@@ -1,8 +1,9 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import os
 import hashlib
 from sql.operators import Concat
+from sql.conditionals import Coalesce
 
 from ..model import ModelView, ModelSQL, fields
 from ..config import config
@@ -54,6 +55,7 @@ class Attachment(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Attachment, cls).__setup__()
+        cls._order.insert(0, ('last_modification', 'DESC'))
         cls._sql_constraints += [
             ('resource_name', 'UNIQUE(resource, name)',
                 'The  names of attachments must be unique by resource!'),
@@ -128,7 +130,7 @@ class Attachment(ModelSQL, ModelView):
             else:
                 try:
                     with open(filename, 'rb') as file_p:
-                        value = buffer(file_p.read())
+                        value = fields.Binary.cast(file_p.read())
                 except IOError:
                     pass
         return value
@@ -191,6 +193,11 @@ class Attachment(ModelSQL, ModelView):
         return (self.write_date if self.write_date else self.create_date
             ).replace(microsecond=0)
 
+    @staticmethod
+    def order_last_modification(tables):
+        table, _ = tables[None]
+        return [Coalesce(table.write_date, table.create_date)]
+
     def get_last_user(self, name):
         return (self.write_uid.rec_name if self.write_uid
             else self.create_uid.rec_name)
